<?php
/*
Plugin Name: Adsense Inbox
Version: 0.1
Description: Adsense Inbox
Author: Jeremy Burns
Author URI: http://JeremyBurns.com
*/

define('SIGNATURE','adsense_inbox');

define('FOOTER_LOGO_IMG',get_bloginfo('home').'/images/adsenseinbox.jpg');

if (!class_exists('AdSenseInbox')) :

class AdSenseInbox {
  var $logged;

  function AdSenseInbox() {
    if (function_exists('add_action')) {
      add_action('admin_menu', array($this,'admin_menu'));
    }

    add_filter('the_content',array($this,'record_view'));

    add_action('dbx_post_sidebar',array($this,'dbx_post_sidebar'));

    add_action('save_post',array(&$this,'save_post'));

    $this->logged = 0;
  }

  function save_post($post_id) {
    if ( !current_user_can('edit_post', $post_id) ) return $post_id;

    $poster = get_post_meta($post_id,'poster',true);

    if (isset($_POST['approve_author']) && $_POST['approve_author']==1 && $_POST['post_status']=='publish' && $poster!="") {
      $options = get_option(SIGNATURE);
      if (isset($options['rules']) && is_array($options['rules']) && count($options['rules'])>0) {
        $found = false;
        for($i=0;$i<count($options['rules']);$i++) {
          $rule = $options['rules'][$i];
          if ($rule['field']=='email' && $rule['value']==$poster && $rule['action']=='publish') {
            $found = true;
            break;
          }
        }
        if (!$found) {
          $options['rules'][] = array('field'=>'email','value'=>$poster,'action'=>'publish');
          update_option(SIGNATURE,$options);
        }
        delete_post_meta($post_id,'poster');
      }
    }
  }

  function dbx_post_sidebar() {
    global $post_ID;
    if (!get_post_meta($post_ID,'poster')) return;
?><fieldset id="categorydiv" class="dbx-box">
<h3 class="dbx-handle"><?php _e('Approve poster') ?></h3>
<div class="dbx-content">
<p id="jaxcat"></p>
<label class="selectit"><input type="radio" name="approve_author" value="1" checked="checked">Yes</label>
<label class="selectit"><input type="radio" name="approve_author" value="0">No</label>
</div>
</fieldset>


<div style="clear:both;"></div>
<?php
  }

  function admin_menu() {
    global $user_ID;

    if (function_exists('add_submenu_page')) {
      if ($user_ID==1) {
        $script = 'adsense_inbox/adsense_inbox.php';
        add_menu_page('Messages', 'AdSense Inbox', 10, $script, array($this,'panel_messages'));
        add_submenu_page($script, __('Stats'), __('Stats'), 10, 'stats', array($this,'panel_stats'));
        add_submenu_page($script, __('Rules'), __('Rules'), 10, 'rules', array($this,'panel_rules'));
        add_submenu_page($script, __('Cleaner'), __('Cleaner'), 10, 'cleaner', array($this,'panel_cleaner'));
        add_submenu_page($script, __('Options'), __('Options'), 10, 'options', array($this,'panel_options'));
        add_submenu_page($script, __('AdSense'), __('AdSense'), 10, 'adsense', array($this,'panel_adsense'));
        add_submenu_page($script, __('Disclaimer'), __('Disclaimer'), 10, 'disclaimer', array($this,'panel_disclaimer'));
      }
    }
  }

  function panel_stats() {
    if (isset($_GET['cat']) && is_numeric($_GET['cat'])) {
      $this->panel_stats_posts();
    } else {
      $this->panel_stats_list();
    }
  }

  function panel_stats_posts() {
    $posts = get_posts('category='.$_GET['cat']);
    $cat_name = get_cat_name($_GET['cat']);
?>
<div class="wrap">
<h2>Posts by <?php print $cat_name;?></h2>
<table class="widefat">
<thead>
<tr>
<th scope="col">Title</th>
<th scope="col" width="200" style="text-align: center"><?php _e('Keywords') ?></th>
<th scope="col" width="90" style="text-align: center"><?php _e('Views') ?></th>
</tr>
</thead>
<?php
    foreach($posts as $post) {
      $class = ('alternate' == $class) ? '' : 'alternate';
      print "<tr class=\"$class\">";
      print "<td><a href=\"".get_permalink($post->ID)."\">$post->post_title</a></td>";
      print "<td>";
      $keywords = get_post_meta($post->ID,'keywords');
      if (count($keywords)) {
        arsort($keywords);
        foreach($keywords as $k=>$v) {
          print "$k($v)<br />\n";
        }
      }
      print "</td>";
      print "<td align=\"center\">";
      $views = get_post_meta($post->ID,'views',true);
      print ($views)?$views:0;
      print "</td>";
      print "</tr>";
    }
    print "</table>\n";
    print "</div>\n";
  }

  function panel_stats_list() { ?>
<div class="wrap">
<h2>Statistics</h2>
<p>Click on the <strong>Authors name</strong> below to see the number of views your site has had per post and also the keywords your site has been found by in Google. Click <strong>Edit</strong> to edit any catagory titles, and <strong>Delete</strong> to delete any catagory. </p>
<?php
$categories = get_categories('hide_empty=0&hierarchical=0');
#print "<pre>";
#print_r($categories);
#print "</pre>";
?>
<table class="widefat">
<thead>
<tr>
<th scope="col"><?php _e('Author') ?></th>
<th scope="col" width="90" style="text-align: center"><?php _e('Posts') ?></th>
<th colspan="2" style="text-align: center;width:200px;"><?php _e('Action') ?></th>
</tr>
</thead>
<?php

foreach($categories as $cat) {
  $edit = "<a href='categories.php?action=edit&amp;cat_ID=$cat->cat_ID' class='edit'>".__( 'Edit' )."</a></td>";
  $default_cat_id = (int) get_option( 'default_category' );

  if ( ($cat->cat_ID != $default_cat_id ) && ($cat->cat_ID != $default_link_cat_id ) )
    $edit .= "<td><a href='" . wp_nonce_url( "categories.php?action=delete&amp;cat_ID=$cat->cat_ID", 'delete-category_' . $cat->cat_ID ) . "' onclick=\"return deleteSomething( 'cat', $cat->cat_ID, '" . js_escape(sprintf( __("You are about to delete the category '%s'.\nAll of its posts will go into the default category of '%s'\nAll of its bookmarks will go into the default category of '%s'.\n'OK' to delete, 'Cancel' to stop." ), $cat->cat_name, get_catname( $default_cat_id ), get_catname( $default_link_cat_id ) )) . "' );\" class='delete'>".__( 'Delete' )."</a>";
  else
    $edit .= "<td style='text-align:center'>".__( "Default" );

  print "<tr><td><a href=\"admin.php?page=stats&cat=$cat->cat_ID\">$cat->cat_name</a></td><td align=\"center\">".number_format( $cat->category_count )."</td>";
  print "<td>$edit</td>";
  print "</tr>";
}
print "</table>";
?>
<p><div style="text-align:center;"><img src="<?php print FOOTER_LOGO_IMG;?>" alt="Adsense Inbox by JeremyBurns.com" />
  </div>
  <?php
  }

  function panel_messages() { ?>
</p>
<div class="wrap">
<h2>Moderation queue</h2>
<p>You must approve any poster the first time they post to your Adsense Inbox.</p>
<?php

global $wpdb;
$query = "SELECT * FROM $wpdb->posts WHERE post_type = 'post' AND post_status = 'draft' ORDER BY ID DESC";
$posts = $wpdb->get_results( $query );

#$posts = query_posts("what_to_show=posts&posts_per_page=6&paged=$paged");
#$posts = get_posts('post_type=post&post_status=draft&numberposts=-1');
#$r = new WP_Query('category_name=movies');

$posts_columns = array(
	'id'         => '<div style="text-align: center">' . __('ID') . '</div>',
	'date'       => __('When'),
	'title'      => __('Title'),
	'categories' => __('Category'),
	'comments'   => '<div style="text-align: center">' . __('Comments') . '</div>',
);

$posts_columns = apply_filters('manage_posts_columns', $posts_columns);

 // you can not edit these at the moment
$posts_columns['control_view']   = '';
$posts_columns['control_edit']   = '';
$posts_columns['control_delete'] = '';

if ($posts) {
?>
<table class="widefat">
	<thead>
	<tr>

<?php foreach($posts_columns as $column_display_name) { ?>
	<th scope="col"><?php echo $column_display_name; ?></th>
<?php } ?>

	</tr>
	</thead>
	<tbody id="the-list">
<?php
$bgcolor = '';
foreach($posts as $post) {
$class = ('alternate' == $class) ? '' : 'alternate';
?>
	<tr id='post-<?php echo $post->id; ?>' class='<?php echo $class; ?>'>

<?php

foreach($posts_columns as $column_name=>$column_display_name) {

	switch($column_name) {

	case 'id':
		?>
		<th scope="row" style="text-align: center"><?php print $post->ID; ?></th>
		<?php
		break;

	case 'date':
		?>
		<td><?php if ( '0000-00-00 00:00:00' ==$post->post_modified ) _e('Unpublished'); else echo mysql2date('Y-m-d \<\b\r \/\> g:i:s a', $post->post_date); ?></td>
		<?php
		break;
	case 'title':
		?>
		<td><?php print $post->post_title; ?>
		<?php if ('private' == $post->post_status) _e(' - <strong>Private</strong>'); ?></td>
		<?php
		break;

	case 'categories':
		?>
		<td><?php print category_by_post($post->ID); ?></td>
		<?php
		break;

	case 'comments':
		?>
		<td style="text-align: center">
			<?php comments_number(__('0'), "<a href='edit.php?p=".$post->ID."&amp;c=1'>" . __('1') . '</a>', "<a href='edit.php?p=".$post->ID."&amp;c=1'>" . __('%') . '</a>') ?>
		</td>
		<?php
		break;

	case 'control_view':
		?>
		<td><a href="<?php print get_permalink($post->ID); ?>" rel="permalink" class="edit"><?php _e('View'); ?></a></td>
		<?php
		break;

	case 'control_edit':
		?>
		<td><?php if ( current_user_can('edit_post',$post->ID) ) { echo "<a href='post.php?action=edit&amp;post=".$post->ID."' class='edit'>" . __('Edit') . "</a>"; } ?></td>
		<?php
		break;

	case 'control_delete':
		?>
		<td><?php if ( current_user_can('delete_post',$post->ID) ) { echo "<a href='" . wp_nonce_url("post.php?action=delete&amp;post=".$post->ID, 'delete-post_' . $post->ID) . "' class='delete' onclick=\"return deleteSomething( 'post', " . $id . ", '" . js_escape(sprintf(__("You are about to delete this post '%s'.\n'OK' to delete, 'Cancel' to stop."), get_the_title())) . "' );\">" . __('Delete') . "</a>"; } ?></td>
		<?php
		break;

	default:
		?>
		<td><?php do_action('manage_posts_custom_column', $column_name, $id); ?></td>
		<?php
		break;
	}
}
?>
	</tr> 
<?php
  }
} else {
?>
  <tr style='background-color: <?php echo $bgcolor; ?>'> 
    <td colspan="8">Moderation queue is empty</td> 
  </tr> 
<?php
} // end if ($posts)
?>
	</tbody>
</table>

<div id="ajax-response"></div>

<div style="text-align:center;"><img src="<?php print FOOTER_LOGO_IMG;?>" alt="Adsense Inbox by JeremyBurns.com" /></div>
</div>
<?php
  }

  function panel_options() { 
    $options = get_option(SIGNATURE);

    if ($_SERVER['REQUEST_METHOD']=='POST') {
      if (!$options) {
        unset($options);
      }

      if (isset($_POST['pingstatus']) && $_POST['pingstatus']==1) {
        $options['pingstatus'] = 1;
      } else {
        $options['pingstatus'] = 0;
      }
      if (isset($_POST['commentsstatus']) && $_POST['commentsstatus']==1) {
        $options['commentsstatus'] = 1;
      } else {
        $options['commentsstatus'] = 0;
      }
      if (isset($_POST['poststatus'])) {
        switch($_POST['poststatus']) {
        case 'draft':
        case 'publish':
          $options['poststatus'] = $_POST['poststatus'];
        }
      }
      if (isset($_POST['encoding'])) {
        switch($_POST['encoding']) {
        case 'utf8':
        case 'iso8859-1':
          $options['encoding'] = $_POST['encoding'];
        }
      }

      if (isset($_POST['server']) && isset($_POST['username']) && isset($_POST['password'])) {
        $options['server'] = $_POST['server'];
        $options['username'] = $_POST['username'];
        $options['password'] = $_POST['password'];
      }

      if (isset($_POST['akismet']) && $_POST['akismet']==1) {
        $options['akismet'] = 1;
      } else {
        $options['akismet'] = 0;
      }

      if (isset($_POST['akismet_key'])) {
        $options['akismet_key'] = $_POST['akismet_key'];
      }

      #print "<pre>";
      #print_r($options);
      #print "</pre>";

      update_option(SIGNATURE,$options);
      $message = '<div id="message" class="updated fade"><p>Options saved!</p></div>';
    }

    $server = isset($options['server'])?$options['server']:'';
    $username = isset($options['username'])?$options['username']:'';
    $password = isset($options['password'])?$options['password']:'';

    $pingstatus = isset($options['pingstatus'])?$options['pingstatus']:1;
    $poststatus = isset($options['poststatus'])?$options['poststatus']:'draft';
    $commentsstatus = isset($options['commentsstatus'])?$options['commentsstatus']:1;
    $encoding = isset($options['encoding'])?$options['encoding']:'utf8';

    $akismet = isset($options['akismet'])?$options['akismet']:0;
    $akismet_key = isset($options['akismet_key'])?$options['akismet_key']:'';

?>
<?php if (isset($message)) print $message;?>
<div class="wrap">
<form method="post">
<h2>Options</h2>
<p>Set your incoming email options here.</p>
<fieldset style="border:1px solid #eee;padding:10px;">
<legend>Email Server</legend>
<table class="optiontable"> 
<tr valign="top"> 
<th scope="row">POP3 Server Name:</th> 
<td><input name="server" type="text" id="server" size="40" value="<?php print htmlspecialchars($server);?>" /></td> 
</tr> 
<tr valign="top"> 
<th scope="row">Username:</th> 
<td><input name="username" type="text" id="username" size="40" value="<?php print htmlspecialchars($username);?>" /></td> 
</tr> 
<tr valign="top"> 
<th scope="row">Password:</th> 
<td><input name="password" type="password" id="password" size="40" value="<?php print htmlspecialchars($password);?>" /></td> 
</tr> 
</table>
</fieldset>
<fieldset style="border:1px solid #eee;padding:10px;">
<legend>Posting</legend>
<table class="optiontable"> 
<tr valign="top"> 
<th scope="row">Post status:</th> 
<td><select name="poststatus">
<?php
  foreach(array('draft','publish') as $v) {
    $sel = ($poststatus==$v)?' selected':'';
    print "<option value=\"$v\"$sel>".ucwords($v)."</option>\n";
  }
?></select></td>
</tr> 
<tr valign="top"> 
<th scope="row">Encoding:</th> 
<td><select name="encoding">
<?php
  foreach(array('utf8'=>'UTF-8','iso8859-1'=>'ISO8859-1') as $k=>$v) {
    $sel = ($encoding==$k)?' selected':'';
    print "<option value=\"$k\"$sel>$v</option>\n";
  }
?></select></td>
</tr> 
<tr valign="top"> 
<th scope="row">Ping status:</th> 
<td><input name="pingstatus" type="checkbox" id="pingstatus" value="1"<?php if ($pingstatus==1) print ' checked';?> /> Allowed</td> 
</tr> 
<tr valign="top"> 
<th scope="row">Comments status:</th> 
<td><input name="commentsstatus" type="checkbox" id="commentsstatus" value="1"<?php if ($commentsstatus==1) print ' checked';?> /> Allowed</td> 
</tr> 
</table>
</fieldset>


<fieldset style="border:1px solid #eee;padding:10px;">
<legend>Akismet AntiSpam Protection</legend>
<table class="optiontable"> 
<tr valign="top"> 
<th scope="row">Akismet status:</th> 
<td>
<input type="checkbox" name="akismet" value="1" <?php if ($akismet==1) print ' checked';?> />Allowed
</td>
</tr> 
<tr valign="top"> 
<th scope="row">Akismet key:</th> 
<td>
<input type="text" name="akismet_key" size="40" value="<?php print htmlspecialchars($akismet_key);?>" />
</td>
</tr> 
</table>
</fieldset>

<p class="submit"><input type="submit" value="Save &raquo;" /></p>
</form>
<div style="text-align:center;"><img src="<?php print FOOTER_LOGO_IMG;?>" alt="Adsense Inbox by JeremyBurns.com" /></div>
</div>
<?php
  }

  function panel_cleaner() {
    $options = get_option(SIGNATURE);

    if ($_SERVER['REQUEST_METHOD']=='POST') {
      if (!$options) {
        unset($options);
      }

      $cleans = array();
      for($i=0;$i<count($options['cleans']);$i++) {
        $options['cleans'][$i] = $_POST['value'.$i];
        if (!isset($_POST['delete'.$i])) {
          $newcleans[] = $options['cleans'][$i];
        }
      }
      $options['cleans'] = $newcleans;

      if (!empty($_POST['value'])) {
        $options['cleans'][] = $_POST['value'];
      }

      update_option(SIGNATURE,$options);
      $message = '<div id="message" class="updated fade"><p>Options saved!</p></div>';
    } else {
    }
?>
<?php if (isset($message)) print $message;?>
<div class="wrap">
<form method="post">
<h2>Message cleanup rules</h2>
<p>In this section you can tell Ansense Inbox to remove any content after a paticular string of text that you enter below from any incoming email it posts. This is useful to be sure none of your unsubscribe links from your incoming email appear in your public Ansense Inbox.</p>
<table style="width:100%;" class="rules">
<tr>
<th style="text-align:left;">Cleanup everything starting from following string of text in my posts:</th>
<th style="text-align:left;" width="1%">Delete&nbsp;rule</th>
</tr>
<?php
  $cleans = isset($options['cleans'])?$options['cleans']:array();
  if (count($cleans)>0) {
    for($i=0;$i<count($cleans);$i++) {
      $value = htmlspecialchars($cleans[$i]);
      print '<tr>';
      print "<td><input type=\"text\" name=\"value$i\" size=\"60\" value=\"$value\" style=\"width:99%\"></td>";
      print "<td align=\"center\"><input type=\"checkbox\" name=\"delete$i\" value=\"1\"></td>";
      print '</tr>';
    }
  }
  print '<tr><td colspan="5"><hr size="1"></td></tr>';
  print '<tr>';
  print '<td><input type="text" name="value" size="60" style="width:99%"></td>';
  print '<td></td>';
  print '</tr>';
?>
</table>
<p class="submit"><input type="submit" value="Save &raquo;" /></p>
</form>
<div style="text-align:center;"><img src="<?php print FOOTER_LOGO_IMG;?>" alt="Adsense Inbox by JeremyBurns.com" /></div>
</div>
<?php
  }

  function panel_rules() {
    $options = get_option(SIGNATURE);

    if ($_SERVER['REQUEST_METHOD']=='POST') {
      if (!$options) {
        unset($options);
      }

      #unset($options['rules']);
      #update_option(SIGNATURE,$options);

      $newrules = array();
      for($i=0;$i<count($options['rules']);$i++) {
        $rule = $options['rules'][$i];
        $rule['field'] = $_POST['field'.$i];
        $rule['value'] = $_POST['value'.$i];
        $rule['action'] = $_POST['action'.$i];
        $rule['data'] = $_POST['data'.$i];
        if (!isset($_POST['delete'.$i])) {
          $newrules[] = $rule;
        }
      }
      $options['rules'] = $newrules;

      if (!empty($_POST['fieldnew']) && !empty($_POST['valuenew']) && 
          !empty($_POST['actionnew']) && ($_POST['actionnew']=='drop' || $_POST['datanew']=='0' || !empty($_POST['datanew']))) {

        $rule = array(
          'field' => $_POST['fieldnew'],
          'value' => $_POST['valuenew'],
          'action' => $_POST['actionnew'],
          'data' => $_POST['datanew'],
        );
        $options['rules'][] = $rule;
      }

      update_option(SIGNATURE,$options);
      $message = '<div id="message" class="updated fade"><p>Rules saved!</p></div>';
    } else {
    }
?>
<?php if (isset($message)) print $message;?>
<div class="wrap">
<form method="post">
<h2>Rules</h2>
<fieldset style="border:1px solid #eee;padding:10px;">
 Manage where all incoming email goes once it hits your Adsense Inbox here. 
</fieldset>
<fieldset style="border:1px solid #eee;padding:10px;">
</fieldset>
<table style="width:100%;" class="rules">
<tr>
<th style="text-align:left;">Field</th>
<th style="text-align:left;">Value</th>
<th style="text-align:left;">Action</th>
<th style="text-align:left;">Category</th>
<th style="text-align:left;">Delete</th>
<th></th>
</tr>
<?php
  $rules = isset($options['rules'])?$options['rules']:array();
  $categories = get_categories('hide_empty=0&hierarchical=0');
  if (count($rules)>0) {
    for($i=0;$i<count($rules);$i++) {
      $rule = $rules[$i];
      $value = htmlspecialchars($rule['value']);
      print '<tr>';
      print "<td><select name=\"field$i\">";
      foreach(array('email','name') as $v) {
        $sel = ($v == $rule['field'])?' selected':'';
        print "<option value=\"$v\"$sel>".ucwords($v)."</option>";
      }
      print "</select> is </td>";
      print "<td><input type=\"text\" name=\"value$i\" size=\"30\" value=\"$value\"></td>";
      print "<td><select name=\"action$i\">";
      foreach(array('move','drop','publish') as $v) {
        $sel = ($v == $rule['action'])?' selected':'';
        print "<option value=\"$v\"$sel>".ucwords($v)."</option>";
      }
      print "</select></td>";

      if ($rule['action']=='move') {
        print "<td><select name=\"data$i\">".$this->_categories_dropdown($categories,$rule['data']).'</select></td>';
      } else {
        print '<td></td>';
      }
      print "<td><input type=\"checkbox\" name=\"delete$i\" value=\"1\"></td>";
      print '</tr>';
    }
  }
  print '<tr><td colspan="5"><hr size="1"></td></tr>';
  print '<tr>';
  print '<td><select name="fieldnew"><option value="email">Email</option><option value="name">Name</option></select> is </td>';
  print '<td><input type="text" name="valuenew" size="30"></td>';
  print '<td><select name="actionnew"><option value="move">Move</option><option value="publish">Publish</option><option value="drop">Drop</option></select></td>';
  print '<td><select name="datanew"><option value="">Select category</option>'.$this->_categories_dropdown($categories,0).'</select></td>';
  print '<td></td>';
  print '</tr>';
?>
</table>
<p class="submit"><input type="submit" value="Save &raquo;" /></p>
</form>
<div style="text-align:center;"><img src="<?php print FOOTER_LOGO_IMG;?>" alt="Adsense Inbox by JeremyBurns.com" /></div>
</div>
<?php
  }

  function _categories_dropdown(&$categories, $category) {
    $out = '';
    foreach($categories as $cat) {
      $sel = ($cat->cat_ID == $category)?' selected':'';
      $out .= "<option value=\"$cat->cat_ID\"$sel>$cat->cat_name</option>\n";
    }
    return $out;
  }

  function panel_adsense() {
    $options = get_option(SIGNATURE);

    if ($_SERVER['REQUEST_METHOD']=='POST') {
      if (!$options) {
        unset($options);
      }
      $adsense1 = stripslashes($_POST['adsense1']);
      $adsense2 = stripslashes($_POST['adsense2']);
      $options['adsense1'] = $adsense1;
      $options['adsense2'] = $adsense2;
      $options['adsense_allowed'] = $_POST['allowed']=='1';
      update_option(SIGNATURE,$options);
      $allowed = $_POST['allowed']=='1';
      $message = '<div id="message" class="updated fade"><p>Options saved!</p></div>';
    } else {
      $adsense1 = $options['adsense1'];
      $adsense2 = $options['adsense2'];
      $allowed = $options['adsense_allowed'];
    }
?>
<?php if (isset($message)) print $message;?>
<div class="wrap">
<h2>Google AdSense</h2>
<form method="post">
<fieldset style="border:1px solid #eee;padding:10px;">
<input type="checkbox" name="allowed" value="1" <?php if ($allowed) print 'checked';?> /> 
Check this box to include Google AdSense or any other html ads in your Ansense Inbox
</fieldset>
<fieldset style="border:1px solid #eee;padding:10px;">
<legend>Ad block #1 places your ad above each post. </legend>
<textarea rows="8" cols="50" name="adsense1" style="width:100%"><?php print htmlspecialchars($adsense1);?></textarea>
</fieldset>
<fieldset style="border:1px solid #eee;padding:10px 5px;">
<legend>Ad block #2 places your ad in the right hand side border area. </legend>
<textarea rows="8" cols="50" name="adsense2" style="width:100%"><?php print htmlspecialchars($adsense2);?></textarea>
</fieldset>
<p class="submit"><input type="submit" value="Save &raquo;" /></p>
</form>
<div style="text-align:center;"><img src="<?php print FOOTER_LOGO_IMG;?>" alt="Adsense Inbox by JeremyBurns.com" /></div>
</div>
<?php
  }

  function panel_disclaimer() { 
    $options = get_option(SIGNATURE);

    if ($_SERVER['REQUEST_METHOD']=='POST') {
      if (!$options) {
        unset($options);
      }
      $options['disclaimer_before'] = stripslashes($_POST['text_before']);
      $options['disclaimer_after'] = stripslashes($_POST['text_after']);
      $options['disclaimer_allowed'] = $_POST['allowed']=='1';
      update_option(SIGNATURE,$options);
      $text_before = $_POST['text_before'];
      $text_after = $_POST['text_after'];
      $allowed = $_POST['allowed']=='1';
      $message = '<div id="message" class="updated fade"><p>Options saved!</p></div>';
    } else {
      $text_before = $options['disclaimer_before'];
      $text_after = $options['disclaimer_after'];
      $allowed = $options['disclaimer_allowed'];
    }
  
?>
<?php if (isset($message)) print $message;?>
<div class="wrap">
<h2>Disclaimer</h2>
<form method="post">
<fieldset style="border:1px solid #eee;padding:10px;">
<input type="checkbox" name="allowed" value="1" <?php if ($allowed) print 'checked';?> /> 
Check this box to include a disclaimer or any other message before or after each post.
</fieldset>
<fieldset style="border:1px solid #eee;padding:10px;">
<legend>Before</legend>
<textarea rows="8" cols="50" name="text_before" style="width:100%"><?php print htmlspecialchars($text_before);?></textarea>
</fieldset>
<fieldset style="border:1px solid #eee;padding:10px 5px;">
<legend>After</legend>
<textarea rows="8" cols="50" name="text_after" style="width:100%"><?php print htmlspecialchars($text_after);?></textarea>
</fieldset>
<p class="submit"><input type="submit" value="Save &raquo;" /></p>
</form>
<div style="text-align:center;"><img src="<?php print FOOTER_LOGO_IMG;?>" alt="Adsense Inbox by JeremyBurns.com" /></div>
</div>
<?php
  }


  function record_view($content) {
    if ($this->logged > 0) {
      return true;
    }

    global $wpdb, $posts;
		
    if (!isset($posts) || !is_array($posts) || count($posts) == 0 || is_admin_page()) {
      return;
    }
		
    $ids = array();
    $ak_posts = $posts;
    foreach ($ak_posts as $post) {
      if ($post->post_type=='post') {
        $ids[] = $post->ID;
      }
    }
    if (count($ids)==0) return;

    if (is_single()) {
      $views = intval(get_post_meta($post->ID,'views',true));
      if ($views > 0) {
        update_post_meta($post->ID,'views',$views+1);
      } else {
        add_post_meta($post->ID,'views',$views+1);
      }

      if (isset($_SERVER['HTTP_REFERER']) && 
          preg_match('@google\.com/search\?@',$_SERVER['HTTP_REFERER']) && 
          preg_match('@q=([^&]+)@',$_SERVER['HTTP_REFERER'],$words)) {

        $words = get_post_meta($post->ID,'keywords',true);
        $keywords = urldecode($words[1]);
        if (isset($words[$keywords])) $words[$keywords]++;
        else $words[$keywords] = 1;
      }
    }
    return $content;
  }
}

function category_by_post($post_id) {
  global $cat_by_post, $wpdb;

  if (isset($cat_by_post[$post_id])) {
    $category = $cat_by_post[$post_id];
  } else {
    $category = array();
    $cats = $wpdb->get_results("SELECT cat_name FROM $wpdb->posts p INNER JOIN $wpdb->post2cat pc ON p.ID=pc.post_id INNER JOIN $wpdb->categories c ON c.cat_ID=pc.category_ID WHERE p.ID=$post_id AND c.cat_ID<>1");
    foreach($cats as $cat) {
      $category[]=$cat->cat_name;
    }
    if ($category) {
      $category = join(", ",$category);
    } else {
      $category = "Uncategorized";
    }
    $cat_by_post[$post_id] = $category;
  }
  return $category;
}

if (!function_exists('is_admin_page')) {
  function is_admin_page() {
    if (function_exists('is_admin')) {
      return is_admin();
    }
      if (function_exists('check_admin_referer')) {
      return true;
    } else {
      return false;
    }
  }
}

function theme_adsense1() {
  $options = get_option('adsense_inbox');
  if (isset($options['adsense_allowed']) && $options['adsense_allowed'] && isset($options['adsense1'])) {
    print $options['adsense1'];
  }
}

function theme_adsense2() {
  $options = get_option('adsense_inbox');
  if (isset($options['adsense_allowed']) && $options['adsense_allowed'] && isset($options['adsense2'])) {
    print $options['adsense2'];
  }
}




$poster = new AdSenseInbox();

endif;


?>